mod db;
mod server;

fn main() {
    tracing_subscriber::fmt::init();

    tracing::info!("Initializing database and running migrations");

    let pool = db::initialize_db("data/db.sqlite3", true).unwrap();

    let ctx = server::Context { pool };
    let app = server::app().with_state(ctx);

    let rt = tokio::runtime::Builder::new_multi_thread()
        .enable_all()
        .build()
        .unwrap();

    let address = "0.0.0.0:8080";

    tracing::info!("Starting server on {address}");

    rt.block_on(async {
        let listener = tokio::net::TcpListener::bind(address).await.unwrap();
        axum::serve(listener, app.into_make_service())
            .await
            .unwrap()
    });
}
